@@ -17,6 +17,7 @@
 
 #include "cacheproviderplugin.h"
 #include "cacheprovider.h"
+#include "config.h"
 
 CacheProvider::RequestEntry::RequestEntry(const RequestType &type, const QString &cache) {
 
@@ -62,7 +63,8 @@ bool CacheProvider::RequestQueue::add(const RequestEntry::RequestType &type, con
 
   // ignore detail requests if there's already one being processed. This
   // prevents multiple stacked windows from opening on maemo5
-  if(size() && (type == RequestEntry::Detail) && (head()->type() == RequestEntry::Detail)) {
+  if(size() && (type == RequestEntry::Detail) && 
+     (head()->type() == RequestEntry::Detail)) {
     qDebug() << __FUNCTION__ << "supressing addional Detail request";
     return false;
   }
